
Debug Enabling
-------

**Example:**

    <?php

    /*
    Turn off all error reporting, this method should be included on all your pages.
    We recommend putting it in a main method which is used througout your entire application.
    */
    error_reporting(0);

    //or
    ini_set('display_errors','Off'); 

    ?>
	